@@ -82,8 +82,7 @@ EvdevWheelEmuFilterButton(InputInfoPtr pInfo, unsigned int button, int value)
                  * If the button is released early enough emit the button
                  * press/release events
                  */
-                xf86PostButtonEvent(pInfo->dev, 0, button, 1, 0, 0);
-                xf86PostButtonEvent(pInfo->dev, 0, button, 0, 0, 0);
+                EvdevQueueButtonClicks(pInfo, button, 1);
             }
         }
 
@@ -163,10 +162,8 @@ EvdevWheelEmuInertia(InputInfoPtr pInfo, WheelAxisPtr axis, int value)
 
     /* Produce button press events for wheel motion */
     while(abs(axis->traveled_distance) > pEvdev->emulateWheel.inertia) {
-
 	axis->traveled_distance -= inertia;
-	xf86PostButtonEvent(pInfo->dev, 0, button, 1, 0, 0);
-	xf86PostButtonEvent(pInfo->dev, 0, button, 0, 0, 0);
+	EvdevQueueButtonClicks(pInfo, button, 1);
     }
 }
 
@@ -201,8 +198,8 @@ EvdevWheelEmuHandleButtonMap(InputInfoPtr pInfo, WheelAxisPtr pAxis, char* axis_
 	    pAxis->down_button = down_button;
 
 	    /* Update the number of buttons if needed */
-	    if (up_button > pEvdev->buttons) pEvdev->buttons = up_button;
-	    if (down_button > pEvdev->buttons) pEvdev->buttons = down_button;
+	    if (up_button > pEvdev->num_buttons) pEvdev->num_buttons = up_button;
+	    if (down_button > pEvdev->num_buttons) pEvdev->num_buttons = down_button;
 
 	} else {
 	    xf86Msg(X_WARNING, "%s: Invalid %s value:\"%s\"\n",
@@ -285,8 +282,8 @@ EvdevWheelEmuPreInit(InputInfoPtr pInfo)
 
         /* Simpler to check just the largest value in this case */
         /* XXX: we should post this to the server */
-        if (5 > pEvdev->buttons)
-            pEvdev->buttons = 5;
+        if (5 > pEvdev->num_buttons)
+            pEvdev->num_buttons = 5;
 
         /* Display default Configuration */
         xf86Msg(X_CONFIG, "%s: YAxisMapping: buttons %d and %d\n",
@@ -337,15 +334,6 @@ EvdevWheelEmuSetProperty(DeviceIntPtr dev, Atom atom, XIPropertyValuePtr val,
                             16, PropModeReplace, 1,
                             &pEvdev->emulateWheel.inertia, TRUE);
             }
-
-            /* Don't enable with negative timeout */
-            if (pEvdev->emulateWheel.timeout < 0)
-            {
-                pEvdev->emulateWheel.timeout = 200;
-                XIChangeDeviceProperty(dev, prop_wheel_timeout, XA_INTEGER, 16,
-                        PropModeReplace, 1,
-                        &pEvdev->emulateWheel.timeout, TRUE);
-            }
         }
     }
     else if (atom == prop_wheel_button)
